@@ -10,7 +10,7 @@
    as published by the Free Software Foundation; either version
    2 of the License, or (at your option) any later version.
 */
-/* $Id: output.c,v 1.40 2001/02/05 10:32:55 olaf Exp $ */
+/* $Id: output.c,v 1.40.2.1 2001/05/01 21:23:42 olaf Exp $ */
 
 #include "cipe.h"
 
@@ -45,7 +45,13 @@ void cipe_dump_packet(char *title, struct sk_buff *skb, int dumpskb)
 /* An adapted version of Linux 2.1 net/ipv4/ipip.c output routine. */
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,37)
-#define ip_select_ident(h,d) (h)->id=htons(ip_id_count++)
+#define ip_ident(h,d) (h)->id=htons(ip_id_count++)
+#else
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,4,4)
+#define ip_ident(h,d) ip_select_ident(h,d)
+#else
+#define ip_ident(h,d) ip_select_ident(h,d,NULL)
+#endif
 #endif
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,36)
@@ -271,7 +277,7 @@ int cipe_xmit(struct sk_buff *skb, struct NET_DEVICE *dev)
 	iph->ihl        =	sizeof(struct iphdr)>>2;
 	iph->tos        =	tos;
 	iph->tot_len    =	htons(skb->len);
-	ip_select_ident(iph, &rt->u.dst);
+	ip_ident(iph, &rt->u.dst);
         iph->frag_off   =	df;
         iph->ttl        =	ttl;
 	iph->protocol   =	IPPROTO_UDP;
