@@ -10,7 +10,7 @@
    as published by the Free Software Foundation; either version
    2 of the License, or (at your option) any later version.
 */
-/* $Id: sock.c,v 1.33.2.1 2001/02/11 21:42:40 olaf Exp $ */
+/* $Id: sock.c,v 1.33.2.2 2002/05/30 11:49:17 olaf Exp $ */
 
 #include "cipe.h"
 
@@ -211,6 +211,11 @@ struct sk_buff *cipe_decrypt_skb(struct cipe *c, struct sock *sk,
 	goto framerr;
     }
 #endif
+    if (length<cipehdrlen+(c->sockshost?sizeof(struct sockshdr):0)) {
+        printk(KERN_INFO "%s: got short packet from %s\n", c->dev->name,
+               cipe_ntoa(saddr(skb)));
+	goto framerr;
+    }
 
     n=alloc_skb(skb->len, GFP_KERNEL);
     if (!n) {
@@ -388,10 +393,8 @@ struct sk_buff *cipe_decrypt_skb(struct cipe *c, struct sock *sk,
     c->stat.rx_packets++;
     return NULL;
 
-#if 0
  framerr:
     ++c->stat.rx_frame_errors; /* slightly abuse this */
-#endif
  error:
     ++c->stat.rx_errors;
     if (n)
